# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-File-Find-Object
Version:	0.3.9
Release:	1.%{__distinit}%{__distvers}
Summary:	Object oriented File::Find replacement
License:	GPL-2.0-or-later OR Artistic-2.0
URL:		https://metacpan.org/release/File-Find-Object
Source0:	https://www.cpan.org/modules/by-module/File/File-Find-Object-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(Class::XSAccessor)
BuildRequires:	perl(Fcntl)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(integer)
BuildRequires:	perl(List::Util)
BuildRequires:	perl(parent)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(blib)
BuildRequires:	perl(File::Path)
BuildRequires:	perl(File::TreeCreate)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(IPC::Open3)
BuildRequires:	perl(lib)
BuildRequires:	perl(Test::File) >= 1.993
BuildRequires:	perl(Test::More) >= 0.88
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
%if 0%{?fedora} < 21 && 0%{?rhel} < 8
Requires:	perl(Class::XSAccessor)
%endif

%description
File::Find::Object does the same job as File::Find but works like an object
and with an iterator. As File::Find is not object oriented, one cannot
perform multiple searches in the same application. The second problem of
File::Find is its file processing: after starting its main loop, one cannot
easily wait for another event and so get the next result.

%prep
%setup -q -n File-Find-Object-%{version}

# Remove spurious exec permissions from docs
chmod -c -x examples/tree

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license LICENSE
%doc Changes examples/ README.md
%{perl_vendorlib}/File/
%{_mandir}/man3/File::Find::Object.3*
%{_mandir}/man3/File::Find::Object::Base.3*
%{_mandir}/man3/File::Find::Object::PathComp.3*
%{_mandir}/man3/File::Find::Object::Result.3*

%changelog
* Wed Dec 11 2024 Paul Howarth <paul@city-fan.org> - 0.3.9-1
- Update to 0.3.9 (rhbz#2331637)
  - Avoid implicit symbol imports
    https://perl-begin.org/tutorials/bad-elements/#non_explicitly_imported_symbols
- Switch source URL from cpan.metacpan.org to www.cpan.org

* Sat Jul 22 2023 Paul Howarth <paul@city-fan.org> - 0.3.8-1
- Update to 0.3.8
  - Fix use_ok() call (GH#3)

* Fri Jul 14 2023 Paul Howarth <paul@city-fan.org> - 0.3.7-2
- Drop MODULE_COMPAT dependency from Fedora 38 onwards

* Mon Jan  2 2023 Paul Howarth <paul@city-fan.org> - 0.3.7-1
- Update to 0.3.7
  - Fix test failures on Windows (GH#2)
- Use SPDX-format license tag

* Fri Aug 27 2021 Paul Howarth <paul@city-fan.org> - 0.3.6-1
- Update to 0.3.6
  - Split File::TreeCreate off to its own distribution
- Use %%license unconditionally
- Fix dist tags for Alma and Rocky Linux

* Tue Mar 10 2020 Paul Howarth <paul@city-fan.org> - 0.3.5-2
- BR: perl(blib) for t/00-compile.t

* Tue Jan 28 2020 Paul Howarth <paul@city-fan.org> - 0.3.5-1
- Update to 0.3.5
  - Rebuild for order of 'NAME' and 'VERSION' sections in the generated POD
    documentation (VERSION used to appear before NAME)

* Mon Aug 26 2019 Paul Howarth <paul@city-fan.org> - 0.3.4-1
- Update to 0.3.4
  - Now at https://github.com/shlomif/perl-file-find-object
  - tidyall
  - Add *~ files to MANIFEST.SKIP (GH#1)

* Wed Jun  5 2019 Paul Howarth <paul@city-fan.org> - 0.3.2-9
- Modernize spec
  - Switch upstream from search.cpan.org to metacpan.org
  - BR: perl-generators unconditionally
  - BR: perl-interpreter rather than perl
  - Don't explicitly clean buildroot in %%install section
  - Drop explicit %%clean section
  - Drop legacy BuildRoot: and Group: tags

* Sun Jan 15 2017 Paul Howarth <paul@city-fan.org> - 0.3.2-1
- Update to 0.3.2
  - Made the version number consistent across the .pm files
    (https://bitbucket.org/shlomif/perl-file-find-object/issues/1/wrong-version-number)

* Mon Jan  9 2017 Paul Howarth <paul@city-fan.org> - 0.3.1-1
- Update to 0.3.1
  - Fixed an issue with tracking the depth of the inodes when detecting a
    symlink loop

* Mon Sep 12 2016 Paul Howarth <paul@city-fan.org> - 0.3.0-1
- Update to 0.3.0
  - Converted the build system to Dist-Zilla
- Switch to ExtUtils::MakeMaker-based flow

* Wed Aug 24 2016 Paul Howarth <paul@city-fan.org> - 0.2.13-5
- BR: perl-generators where available

* Wed Jun 17 2015 Paul Howarth <paul@city-fan.org> - 0.2.13-2
- Perl 5.22 rebuild

* Wed Apr  8 2015 Paul Howarth <paul@city-fan.org> - 0.2.13-1
- Update to 0.2.13
  - Clarified the documentation regarding the use/return of array references

* Fri Nov 28 2014 Paul Howarth <paul@city-fan.org> - 0.2.12-1
- Update to 0.2.12
  - Made sure no two t/*.t test scripts share temp paths, which caused failure
    with HARNESS_OPTIONS="j9"

* Thu Aug 28 2014 Paul Howarth <paul@city-fan.org> - 0.2.11-3
- Use %%license where possible

* Fri Apr 11 2014 Paul Howarth <paul@city-fan.org> - 0.2.11-2
- Enable Test::TrailingSpace

* Fri Apr 11 2014 Paul Howarth <paul@city-fan.org> - 0.2.11-1
- Import from Fedora
- Update to 0.2.11
- Fix license tag

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.7-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sun Jul 21 2013 Petr Pisar <ppisar@redhat.com> - 0.2.7-3
- Perl 5.18 rebuild

* Wed Jul 03 2013 Christopher Meng <rpm@cicku.me> - 0.2.7-2
- Fix the license
- Fix the files' permissions
- Fill up the BRs

* Sun May 26 2013 Christopher Meng <rpm@cicku.me> - 0.2.7-1
- Initial Package
